@@ -31,6 +31,7 @@ from PrimaITestCaseLibrary.MessageManagment import IIPOptions as IIPOptions
 from PrimaITestCaseLibrary.MessageManagment import IIPOption as IIPOption
 from PrimaITestCaseLibrary.MessageManagment import IIPPacketV6 as HeaderIPv6
 from PrimaITestCaseLibrary.MessageManagment import IPProtocol_Type as IPProtocol_Type
+from PrimaITestCaseLibrary.MessageManagment import IExtensionHeader as IExtensionHeader
 from PrimaITestCaseLibrary.MessageManagment import NetworkProtocols as NetworkProtocols
 from Technica.Databases.Ethernet import Protocols as Protocols
 from PrimaITestCaseLibrary.MessageManagment import ITransportPacket as HeaderTransport
@@ -132,6 +133,8 @@ from Technica.Databases.Can import IMultiplexedPart as IMultiplexedPart
 from Technica.Databases.Can import ISwitchedPduInstance as ISwitchedPduInstance
 from Technica.Databases.Can import ISegmentPosition as ISegmentPosition
 from Technica.Databases.Common import ISecOCConfiguration as ISecOCConfiguration
+from Technica.Databases.Can import IContainedProps as IContainedProps
+from Technica.Databases.Can import HeaderType as HeaderType
 from PrimaITestCaseLibrary.MessageManagment import AutoCalculate as AutoCalculate
 from PrimaITestCaseLibrary.NetWorksConfig import IRecordHandler as IRecordHandler
 from PrimaITestCaseLibrary.NetWorksConfig import IBrspyChannelAdapter as ChannelBrspy
@@ -174,6 +177,7 @@ from Technica.Databases.Ethernet import Package as Package
 from Technica.Databases.Ethernet import Event as Event
 from Technica.Databases.Ethernet import CALLSEMANTIC as CALLSEMANTIC
 from Technica.Databases.Ethernet import IManufacturerMethodExtension as IManufacturerMethodExtension
+from Technica.Databases.Ethernet import SomeIpTP as SomeIpTP
 from Technica.Databases.Ethernet import Method as Method
 from Technica.Databases.Ethernet import IEventGroup as IEventGroup
 from Technica.Databases.Ethernet import Field as Field
